/* This file is part of toroidtoe, a web server implementing a game of
 * five-in-a-row on a grid warped onto a surface of a torus.  This
 * program is intended as a basis for student exercises on courses at
 * Helsinki University of Technology.  This source code is distributed
 * under the GPL.
 *
 * Author: Kenneth Oksanen <cessu@iki.fi>
 */

/* This file implements the artificial intelligence (AI) part of the
   problem: choosing the next move and learning from player games. */

#ifndef INCL_AI
#define INCL_AI  1


#include "game.h"


/* This should be called once when the system starts. */

void ai_init(void);


/* Let the computer find the best possible move (written to *x and *y)
   for the player in turn in the given position.  Level must be a
   variable from one (easy) to, say, eight (hard).  Harder values are
   possible, but they require increasingly much CPU time.  Returns the
   estimated value of the given position.  For example WIN implies
   cross wins with the suggested move. */

value_t ai_move(position_t p, content_t turn,
		int *x, int *y, int level);
		

/* A routine which determines whether either side has won, or if the
   game is drawn.  Returns non-zero if so, and stores the outcome
   (from cross' point of view) into *value_p. */

int game_is_over(position_t p, value_t *value_p);


#endif /* INCL_AI */
