/* This file is part of toroidtoe, a web server implementing a game of
 * five-in-a-row on a grid warped onto a surface of a torus.  This
 * program is intended as a basis for student exercises on courses at
 * Helsinki University of Technology.  This source code is distributed
 * under the GPL.
 *
 * Author: Kenneth Oksanen <cessu@iki.fi>
 */

/* This file implements various generic definitions of the game being
   played. */


#ifndef INCL_GAME
#define INCL_GAME  1


#include <inttypes.h>


/* The possible contents of a square on the torus. */ 
typedef enum { EMPTY = 0, NOUGHT = 1, CROSS = 2, N_CONTENTS = 3 } content_t;

/* Macro to give the opposite turn of a given player.  Doesn't work
   for EMPTY. */
#define OPPOSITE(turn)  (3 - (turn))


/* Dimensions of the playing area. */
#define NX  6
#define NY  6

/* The playing area is represented internally as a two dimensional
   array NX*NY of content_t's. */
typedef content_t position_t[NX][NY];


/* Type used to represent the evaluation of a game position. */
typedef int16_t value_t;

/* Value that indicates win for the first player (cross).  -WIN
   indicates win for the second player (nought).  Draw is represented
   by zero.  Note that even if the search evaluates a position as
   drawn, it only implies neither side will win if they play
   correctly, not that the game would already have ended. */
#define WIN         6000
#define DRAW        0
#define LOSS        (-6000)


#endif
