/* This file is part of toroidtoe, a web server implementing a game of
 * five-in-a-row on a grid warped onto a surface of a torus.  This
 * program is intended as a basis for student exercises on courses at
 * Helsinki University of Technology.  This source code is distributed
 * under the GPL.
 *
 * Author: Kenneth Oksanen <cessu@iki.fi>
 */


/* Main program. */

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <unistd.h>
#include <time.h>

#include "ai.h"
#include "net.h"
#include "session.h"


#define DEFAULT_GRAPHICS_DIR   "."


#ifndef EXIT_FAILURE
  /* EXIT_FAILURE is defined in ISO C standard, and should be defined
     in stdlib.h.  But some headers are not yet up to that, so define
     EXIT_FAILURE if it is not yet defined. */
#define EXIT_FAILURE 1
#endif
#ifndef EXIT_SUCCESS
#define EXIT_SUCCESS  1
#endif


static void usage(const char *argv0)
{
  printf("\
This is toroidtoe, a web server implementing  a game of five-in-a-row\n\
on a grid warped onto a surface of a torus.\n\
Usage: %s [options]\n\
  -g path        Specify the directory containing used images.\n\
  -h             Display this help and exit.\n\
This program is distributed under the GPL.  Original implementation\n\
by Kenneth Oksanen <cessu@iki.fi>\n",
           argv0);
}


int main(int argc, char **argv)
{
  int c;
  const char *graphics_dir = DEFAULT_GRAPHICS_DIR;

  /* Read the command line arguments. */
  while ((c = getopt(argc, argv, "g:h")) != -1)
    switch (c) {
    case 'g':
      graphics_dir = optarg;
      break;
    case 'h':
      usage(argv[0]);
      return EXIT_SUCCESS;
    default:
      fprintf(stderr, "Try `%s -h' for more information.\n", argv[0]);
      return EXIT_FAILURE;
    }
  if (optind + 1 < argc) {
    fprintf(stderr, "Too many command line arguments.\n");
    return EXIT_FAILURE;
  }

  /* Initializations. */
  srandom(getpid() * time(NULL));
  ai_init();
  session_init(graphics_dir);

  /* Start the service. */
  net_event_loop(session_cb);

  /* This line is reached only if something did not work in the
     networking code. */

  return EXIT_FAILURE;
}
